Dataset Parsers
===============

This module contains parsers for different types of dataset metadata and structures.

Base Parser
-----------

.. automodule:: atomworks.ml.datasets.parsers.base
   :members:
   :undoc-members:
   :show-inheritance:

Custom Metadata Parsers
----------------------

.. automodule:: atomworks.ml.datasets.parsers.custom_metadata_row_parsers
   :members:
   :undoc-members:
   :show-inheritance:

Default Metadata Parsers
-----------------------

.. automodule:: atomworks.ml.datasets.parsers.default_metadata_row_parsers
   :members:
   :undoc-members:
   :show-inheritance: 